@@ -85,8 +85,7 @@ gpm_devicekit_get_object_icon (const DkpObject *obj)
 		filename = g_strdup ("gpm-ac-adapter");
 	} else if (obj->type == DKP_DEVICE_TYPE_MONITOR) {
 		filename = g_strdup ("gpm-monitor");
-	} else if (obj->type == DKP_DEVICE_TYPE_BATTERY ||
-		   obj->type == DKP_DEVICE_TYPE_UPS) {
+	} else if (obj->type == DKP_DEVICE_TYPE_UPS) {
 		if (!obj->is_present) {
 			/* battery missing */
 			filename = g_strdup_printf ("gpm-%s-missing", prefix);
@@ -98,6 +97,26 @@ gpm_devicekit_get_object_icon (const DkpObject *obj)
 			index_str = gpm_devicekit_get_object_icon_index (obj);
 			filename = g_strdup_printf ("gpm-%s-%s-charging", prefix, index_str);
 
+		} else if (obj->state == DKP_DEVICE_STATE_DISCHARGING) {
+			index_str = gpm_devicekit_get_object_icon_index (obj);
+			filename = g_strdup_printf ("gpm-%s-%s", prefix, index_str);
+		}
+	} else if (obj->type == DKP_DEVICE_TYPE_BATTERY) {
+		if (!obj->is_present) {
+			/* battery missing */
+			filename = g_strdup_printf ("gpm-%s-missing", prefix);
+
+		} else if (obj->state == DKP_DEVICE_STATE_FULLY_CHARGED) {
+			filename = g_strdup_printf ("gpm-%s-charged", prefix);
+
+		} else if (obj->state == DKP_DEVICE_STATE_UNKNOWN && obj->percentage > 95.0f) {
+			egg_warning ("fixing up unknown %f", obj->percentage);
+			filename = g_strdup_printf ("gpm-%s-charged", prefix);
+
+		} else if (obj->state == DKP_DEVICE_STATE_CHARGING) {
+			index_str = gpm_devicekit_get_object_icon_index (obj);
+			filename = g_strdup_printf ("gpm-%s-%s-charging", prefix, index_str);
+
 		} else if (obj->state == DKP_DEVICE_STATE_DISCHARGING) {
 			index_str = gpm_devicekit_get_object_icon_index (obj);
 			filename = g_strdup_printf ("gpm-%s-%s", prefix, index_str);
@@ -216,7 +235,7 @@ gpm_devicekit_get_object_summary (const DkpObject *obj)
 	} else {
 		egg_warning ("in an undefined state we are not charging or "
 			     "discharging and the batteries are also not charged");
-		description = g_strdup (_("Device state could not be read at this time"));
+		description = g_strdup_printf ("%s (%.1f%%)", type_desc, obj->percentage);
 	}
 	return description;
 }
@@ -278,7 +297,7 @@ gpm_devicekit_get_object_description (const DkpObject *obj)
 		} else {
 			condition = _("Poor");
 		}
-		/* Translators: %i is a percentage and %s the condition (Excellent, Good, ...) */
+		/* Translators: %.1f is a percentage and %s the condition (Excellent, Good, ...) */
 		g_string_append_printf (details, _("<b>Capacity:</b> %.1f%% (%s)\n"),
 					obj->capacity, condition);
 	}
@@ -291,6 +310,7 @@ gpm_devicekit_get_object_description (const DkpObject *obj)
 			g_string_append_printf (details, _("<b>Last full charge:</b> %.1f Wh\n"),
 						obj->energy_full);
 		if (obj->energy_full_design > 0)
+			/* Translators: Design charge is the amount of charge the battery is designed to have when brand new */
 			g_string_append_printf (details, _("<b>Design charge:</b> %.1f Wh\n"),
 						obj->energy_full_design);
 		if (obj->energy_rate > 0)
