@@ -162,7 +162,6 @@ main (int argc, char *argv[])
 	g_option_context_set_translation_domain(context, GETTEXT_PACKAGE);
 	g_option_context_set_summary (context, _("GNOME Power Manager"));
 	g_option_context_parse (context, &argc, &argv, NULL);
-	g_option_context_free (context);
 
 	if (version) {
 		g_print ("Version %s\n", VERSION);
@@ -203,9 +202,12 @@ main (int argc, char *argv[])
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
                                            GPM_DATA G_DIR_SEPARATOR_S "icons");
 
-	/* we have to register with the session as we are starting up with the panel */
+	/* optionally register with the session */
 	session = gpm_session_new ();
-	gpm_session_register_client (session, "gnome-power-manager", getenv ("DESKTOP_AUTOSTART_ID"));
+	if (FALSE) {
+		egg_warning ("register with the session requires logout handling");
+		gpm_session_register_client (session, "gnome-power-manager", getenv ("DESKTOP_AUTOSTART_ID"));
+	}
 
 	/* create a new gui object */
 	manager = gpm_manager_new ();
